@@ -4,7 +4,7 @@ from typing import Any, Dict, Iterator, List, Mapping, Set, Type, Union
 from tango.common import PathOrStr
 from tango.common.exceptions import ConfigurationError
 from tango.common.params import Params
-from tango.step import Step
+from tango.step import Step, StepIndexer
 
 logger = logging.getLogger(__name__)
 
@@ -142,7 +142,7 @@ class StepGraph(Mapping[str, Step]):
         keys = set(d.keys())
         if keys == {"ref"}:
             return True
-        if keys == {"type", "ref"} and d["type"] == "ref":
+        if keys >= {"type", "ref"} and d["type"] == "ref":
             return True
         return False
 
@@ -168,12 +168,21 @@ class StepGraph(Mapping[str, Step]):
             return o.__class__(cls._replace_step_dependencies(i, existing_steps) for i in o)
         elif isinstance(o, (dict, Params)):
             if cls._dict_is_ref(o):
-                return existing_steps[o["ref"]]
+                if "key" in o:
+                    return StepIndexer(existing_steps[o["ref"]], o["key"])
+                else:
+                    return existing_steps[o["ref"]]
             else:
-                return {
+                result = {
                     key: cls._replace_step_dependencies(value, existing_steps)
                     for key, value in o.items()
                 }
+                if isinstance(o, dict):
+                    return result
+                elif isinstance(o, Params):
+                    return Params(result, history=o.history)
+                else:
+                    raise RuntimeError(f"Object {o} is of unexpected type {o.__class__}.")
         elif o is not None and not isinstance(o, (bool, str, int, float)):
             raise ValueError(o)
         return o
@@ -239,6 +248,8 @@ class StepGraph(Mapping[str, Step]):
                 return {key: _to_config(value) for key, value in o.items()}
             elif isinstance(o, Step):
                 return {"type": "ref", "ref": o.name}
+            elif isinstance(o, StepIndexer):
+                return {"type": "ref", "ref": o.step.name, "key": o.key}
             elif o is not None and not isinstance(o, (bool, str, int, float)):
                 raise ValueError(o)
             return o
